
# Slot: predicate


generally one of the predicate values 'provider', 'publisher', 'editor' or 'author'

URI: [biolink:contributor_association_predicate](https://w3id.org/biolink/vocab/contributor_association_predicate)


## Domain and Range

[ContributorAssociation](ContributorAssociation.md) &#8594;  <sub>1..1</sub> [PredicateType](types/PredicateType.md)

## Parents

 *  is_a: [predicate](predicate.md)

## Children


## Used by

 * [ContributorAssociation](ContributorAssociation.md)
